@@ -5,11 +5,6 @@
 */
 
 #include "embeddedimagedata.h"
-#include "extractorcollection.h"
-#include "simpleextractionresult.h"
-#include "writedata.h"
-#include "writercollection.h"
-#include "kfilemetadata_debug.h"
 
 #include <QMimeDatabase>
 
@@ -27,13 +22,10 @@ const QStringList EmbeddedImageData::Private::mMimetypes =
     QStringLiteral("audio/flac"),
     QStringLiteral("audio/mp4"),
     QStringLiteral("audio/mpeg"),
-    QStringLiteral("audio/mpeg3"),
     QStringLiteral("audio/ogg"),
-    QStringLiteral("audio/opus"),
     QStringLiteral("audio/wav"),
     QStringLiteral("audio/x-aiff"),
     QStringLiteral("audio/x-ape"),
-    QStringLiteral("audio/x-mpeg"),
     QStringLiteral("audio/x-ms-wma"),
     QStringLiteral("audio/x-musepack"),
     QStringLiteral("audio/x-opus+ogg"),
