@@ -11,6 +11,7 @@
 #include <KLocalizedString>
 
 #include "formatstrings_p.h"
+#include "icnamematch_p.h"
 
 #include <array>
 
@@ -29,12 +30,20 @@ public:
     const KLazyLocalizedString displayName;
     const QMetaType::Type valueType = QMetaType::UnknownType;
     const FormatFunction formatAsString = FormatStrings::toStringFunction;
+
+    static constexpr auto fromId(Property::Property property) -> const PropertyInfoData*;
+    static auto fromName(const QString& name) -> const PropertyInfoData*;
+
+    static const PropertyInfoData s_Empty;
+    static const std::array<PropertyInfoData, 83> s_allProperties;
+    static const QHash<LcIdentifierName, const PropertyInfoData*> s_propertyHash;
 };
 
-const static PropertyInfoData staticEmptyPropertyInfo{ Property::Empty, false, QStringLiteral("empty") };
+const PropertyInfoData PropertyInfoData::s_Empty{ Property::Empty, false, QStringLiteral("empty"), kli18nc("@label", "Empty") };
 
-const static std::array<PropertyInfoData, 78> staticPropertyInfo
+const std::array<PropertyInfoData, 83> PropertyInfoData::s_allProperties
 {
+    PropertyInfoData{ Property::AssistiveAlternateDescription, true,  QStringLiteral("assistiveDescription"),    kli18nc("@label accessible alt text", "Assistive Description"), QMetaType::QString },
     PropertyInfoData{ Property::Album,                      true,  QStringLiteral("album"),                      kli18nc("@label music album", "Album"),                QMetaType::QString },
     PropertyInfoData{ Property::AlbumArtist,                true,  QStringLiteral("albumArtist"),                kli18nc("@label", "Album Artist"),                     QMetaType::QString },
     PropertyInfoData{ Property::Artist,                     true,  QStringLiteral("artist"),                     kli18nc("@label", "Artist"),                           QMetaType::QString },
@@ -79,6 +88,10 @@ const static std::array<PropertyInfoData, 78> staticPropertyInfo
     PropertyInfoData{ Property::PhotoSaturation,            false, QStringLiteral("photoSaturation"),            kli18nc("@label EXIF", "Saturation"),                  QMetaType::Int },
     PropertyInfoData{ Property::PhotoSharpness,             false, QStringLiteral("photoSharpness"),             kli18nc("@label EXIF", "Sharpness"),                   QMetaType::Int },
     PropertyInfoData{ Property::PhotoWhiteBalance,          false, QStringLiteral("photoWhiteBalance"),          kli18nc("@label EXIF", "White Balance"),               QMetaType::Int },
+    PropertyInfoData{ Property::ColorSpace,                 false, QStringLiteral("colorSpace"),                 kli18nc("@label", "Color Space"),                      QMetaType::QString },
+    PropertyInfoData{ Property::VideoCodec,                 false, QStringLiteral("videoCodec"),                 kli18nc("@label", "Video Codec"),                      QMetaType::QString },
+    PropertyInfoData{ Property::AudioCodec,                 false, QStringLiteral("audioCodec"),                 kli18nc("@label", "Audio Codec"),                      QMetaType::QString },
+    PropertyInfoData{ Property::PixelFormat,                false, QStringLiteral("pixelFormat"),                kli18nc("@label", "Pixel Format"),                     QMetaType::QString },
     PropertyInfoData{ Property::Publisher,                  true,  QStringLiteral("publisher"),                  kli18nc("@label", "Publisher"),                        QMetaType::QString },
     PropertyInfoData{ Property::Label,                      true,  QStringLiteral("label"),                      kli18nc("@label", "Label"),                            QMetaType::QString },
     PropertyInfoData{ Property::ReleaseYear,                false, QStringLiteral("releaseYear"),                kli18nc("@label", "Release Year"),                     QMetaType::Int },
@@ -115,19 +128,35 @@ const static std::array<PropertyInfoData, 78> staticPropertyInfo
     PropertyInfoData{ Property::OriginEmailMessageId,       false, QStringLiteral("originEmailMessageId"),       kli18nc("@label the message ID of an email this file was attached to", "E-Mail Attachment Message ID"), QMetaType::QString }
 };
 
-namespace {
-     auto constexpr propertyDataById(Property::Property property) {
-         for (const auto& p : staticPropertyInfo) {
-             if (p.prop == property)
-                 return &p;
-         }
-         return &staticEmptyPropertyInfo;
-     }
+const QHash<LcIdentifierName, const PropertyInfoData*> PropertyInfoData::s_propertyHash = []()
+{
+    QHash<LcIdentifierName, const PropertyInfoData*> infoHash;
+    infoHash.reserve(s_allProperties.size());
+
+    for (const auto& info: s_allProperties) {
+        infoHash[QStringView(info.name)] = &info;
+    }
+    return infoHash;
+}();
+
+constexpr auto PropertyInfoData::fromId(Property::Property property) -> const PropertyInfoData*
+{
+    for (const auto& p : s_allProperties) {
+        if (p.prop == property)
+            return &p;
+    }
+    return &s_Empty;
 }
 
-PropertyInfo::PropertyInfo(Property::Property property) : d(propertyDataById(property)) {};
+auto PropertyInfoData::fromName(const QString& name) -> const PropertyInfoData*
+{
+    return s_propertyHash.value(LcIdentifierName(name), &s_Empty);
+}
 
-PropertyInfo::PropertyInfo() : d(&staticEmptyPropertyInfo) {};
+
+PropertyInfo::PropertyInfo(Property::Property property) : d(PropertyInfoData::fromId(property)) {};
+
+PropertyInfo::PropertyInfo() : d(&PropertyInfoData::s_Empty) {};
 
 PropertyInfo::PropertyInfo(const PropertyInfo& pi)
     : d(pi.d)
@@ -190,65 +219,19 @@ QString PropertyInfo::formatAsDisplayString(const QVariant &value) const
     }
 }
 
-namespace {
-    class LcPropertyName
-    {
-    public:
-        LcPropertyName(const QString& n) : name(n) {};
-        QString name;
-    };
-
-    constexpr QChar trivialToLower(const QChar &c) {
-        if (c.isUpper()) {
-            return QChar::fromLatin1(c.toLatin1() ^ ('a' ^ 'A'));
-        }
-        return c;
-    }
-
-    inline bool operator==(const LcPropertyName &a, const LcPropertyName &b)
-    {
-        if (a.name.size() != b.name.size()) {
-            return false;
-        }
-        for (int i = 0; i < a.name.size(); i++) {
-            if ((a.name[i] != b.name[i]) && (trivialToLower(a.name[i]) != trivialToLower(b.name[i]))) {
-                return false;
-            }
-        }
-        return true;
-    }
-
-    inline size_t qHash(const LcPropertyName &key, size_t seed = 0)
-    {
-        size_t val = seed;
-        for (const auto& c : key.name) {
-            val ^= qHash(trivialToLower(c));
-        }
-        return val;
-    }
-
-    static const QHash<LcPropertyName, PropertyInfo> propertyHash = []() {
-        QHash<LcPropertyName, PropertyInfo> infoHash;
-        infoHash.reserve(staticPropertyInfo.size());
-
-        for (const auto& info: staticPropertyInfo) {
-            infoHash[info.name] = info.prop;
-        }
-        return infoHash;
-    }();
-}
-
 PropertyInfo PropertyInfo::fromName(const QString& name)
 {
-    return propertyHash.value(LcPropertyName(name));
+    PropertyInfo pi;
+    pi.d = PropertyInfoData::fromName(name);
+    return pi;
 }
 
 QStringList PropertyInfo::allNames()
 {
     static QStringList sNames = []() {
         QStringList names;
-        names.reserve(staticPropertyInfo.size());
-        for (auto info: staticPropertyInfo) {
+        names.reserve(PropertyInfoData::s_allProperties.size());
+        for (auto info: PropertyInfoData::s_allProperties) {
             names.append(info.name);
         }
         return names;
